/* 
bmpchips.c uses a stub to create 64x64 images of colors in rgbp.txt
written by Michael J. Chappell 8/11/10

rgbp.txt and grayp.txt are filters or hand edited copies of rgb.txt
available on most unix systems.

cat rgb.txt | grep -v gray | grep -v grey > rgbp.txt
cat rgb.txt | grep gray > grayp.txt

files are edited so basic gray is in the rgbp.txt, and all colors with
spaces are removed as duplicates.  I also removed grey as it is a
duplicate of gray.

any file of format:
123 123 123 colorname
should work fine.

bmp.stub is the 54 byte header of a 64x64 24bit windows bitmap, which
can be read by almost any graphics program.  It is truncated right
before the gbr data begins.  Keep in mind that bmp stores its color data
in blue green red format.

This file is a hack, demonstrates poor programming practices, no error
checking, but was the easiest way to generate chips that I could come up
with.  It is available in the public domain.

BMPCHIPS.C  MICHAEL J. CHAPPELL  8/12/10
mcsuper5@freeshell.org http://mcsuper5.freeshell.org/bmpchips.html
*/
#include <stdio.h>
#include <stdlib.h>

void help(void);

FILE *fpin, *fpout;
char stub[54];

int main (int argc, char ** argv) {
  int i, j;
  int red, green, blue;
  char colname[255];
  char colnamemod[255];

  if (argc>1) {
    help();
    return 1;
  }

  fpin = fopen("bmp.stub","r");
  for (i=0; i<54; i++) {
    stub[i] = fgetc(fpin);
  }
  fclose(fpin);

  fpin = fopen("rgbp.txt","r");
  while (!feof(fpin)) {
    fscanf(fpin,"%d %d %d %s", &red, &green, &blue, colname);
    sprintf(colnamemod, "bmp/%s.bmp", colname);
    fpout = fopen(colnamemod, "w");
    for (i=0; i<54; i++) fputc(stub[i], fpout);
    for (i=0; i<64; i++) {
      for (j=0; j<64; j++) {
	fputc(blue, fpout);
	fputc(green, fpout);
	fputc(red, fpout);
      }
    }
    fclose(fpout);
  }
  fclose(fpin);

  fpin = fopen("grayp.txt","r");
  while (!feof(fpin)) {
    fscanf(fpin,"%d %d %d %s", &red, &green, &blue, colname);
    sprintf(colnamemod, "bmp/%s.bmp", colname);
    fpout = fopen(colnamemod, "w");
    for (i=0; i<54; i++) fputc(stub[i], fpout);
    for (i=0; i<64; i++) {
      for (j=0; j<64; j++) {
	fputc(blue, fpout);
	fputc(green, fpout);
	fputc(red, fpout);
      }
    }
    fclose(fpout);
  }
  fclose(fpin);
  return 0;
}

void help(void) {
printf("\n\
bmpchips.c uses a stub to create 64x64 images of colors in rgbp.txt\n\
written by Michael J. Chappell 8/11/10\n\
\n\
rgbp.txt and grayp.txt are filters or hand edited copies of rgb.txt\n\
available on most unix systems.\n\
\n\
cat rgb.txt | grep -v gray | grep -v grey > rgbp.txt\n\
cat rgb.txt | grep gray > grayp.txt\n\
\n\
files are edited so basic gray is in the rgbp.txt, and all colors \
with\n\
spaces are removed as duplicates.  I also removed grey as it is a\n\
duplicate of gray.\n\
\n\
any file of format:\n\
123 123 123 colorname\n\
should work fine.\n\
\n\
bmp.stub is the 54 byte header of a 64x64 24bit windows bitmap, which\n\
can be read by almost any graphics program.  It is truncated right\n\
before the gbr data begins.  Keep in mind that bmp stores its color\n\
data in blue green red format.\n\
\n\
This file is a hack, demonstrates poor programming practices, no \
error\n\
checking, but was the easiest way to generate chips that I could come\n\
up with.  It is available in the public domain.\n\
\n\
BMPCHIPS.C  MICHAEL J. CHAPPELL  8/12/10\n\
mcsuper5@freeshell.org http://mcsuper5.freeshell.org/bmpchips.html\n\
\n");
return;
}
